@@ -3,40 +3,7 @@ use gtk::gdk::WindowTypeHint;
 #[cfg(linux)]
 use gtk::prelude::*;
 #[cfg(windows)]
-use windows_sys::Win32::Foundation::PSTR;
-#[cfg(windows)]
 use windows_sys::Win32::UI::WindowsAndMessaging::*;
-use crate::windowclass::WindowClass;
-
-// Default
-
-#[cfg(windows)]
-#[deprecated(since="0.2.2", note="Please enter the values manually instead.")]
-pub const DEFAULT_WINDOW_WIDTH: i32 = 1280;
-#[cfg(linux)]
-#[deprecated(since="0.2.2", note="Please enter the values manually instead.")]
-pub const DEFAULT_WINDOW_WIDTH: i32 = 1280;
-
-#[cfg(windows)]
-#[deprecated(since="0.2.2", note="Please enter the values manually instead.")]
-pub const DEFAULT_WINDOW_HEIGHT: i32 = 720;
-#[cfg(linux)]
-#[deprecated(since="0.2.2", note="Please enter the values manually instead.")]
-pub const DEFAULT_WINDOW_HEIGHT: i32 = 1280;
-
-#[cfg(windows)]
-#[deprecated(since="0.2.2", note="Please enter the values manually instead.")]
-pub const DEFAULT_WINDOW_X: i32 = 500;
-#[cfg(linux)]
-#[deprecated(since="0.2.2", note="Please enter the values manually instead.")]
-pub const DEFAULT_WINDOW_X: i32 = 1280;
-
-#[cfg(windows)]
-#[deprecated(since="0.2.2", note="Please enter the values manually instead.")]
-pub const DEFAULT_WINDOW_Y: i32 = 500;
-#[cfg(linux)]
-#[deprecated(since="0.2.2", note="Please enter the values manually instead.")]
-pub const DEFAULT_WINDOW_Y: i32 = 1280;
 
 // Button Styles
 
@@ -92,13 +59,6 @@ pub const DIALOGSTYLE_QUESTION: MESSAGEBOX_STYLE = 32u32;
 #[cfg(linux)]
 pub const DIALOGSTYLE_NONE: MessageType = gtk::MessageType::Question;
 
-#[cfg(windows)]
-#[deprecated(since="0.2.2", note="Please use DIALOGSTYLE_WARN instead.")]
-pub const DIALOGSTYLE_EXCLAMATION: MESSAGEBOX_STYLE = 48u32;
-#[cfg(linux)]
-#[deprecated(since="0.2.2", note="Please use DIALOGSTYLE_WARN instead.")]
-pub const DIALOGSTYLE_EXCLAMATION: MessageType = gtk::MessageType::Warning;
-
 #[cfg(windows)]
 pub const DIALOGSTYLE_WARN: MESSAGEBOX_STYLE = 48u32;
 #[cfg(linux)]
