@@ -1,3 +1,4 @@
+use crate::Event;
 use windows_sys::Win32::UI::WindowsAndMessaging::MESSAGEBOX_STYLE;
 
 #[cfg(windows)]
@@ -54,36 +55,37 @@ impl MessageBox {
     ///     msg_box.show(BUTTONSTYLE_OK,DIALOGSTYLE_INFO,DIALOGHINT_MODAL);
     /// }
     /// ```
-    #[cfg(windows)]
+
     pub fn show(
         &self,
         button_style: MESSAGEBOX_STYLE,
         dialog_style: MESSAGEBOX_STYLE,
         dialog_hint: u64,
-    ) -> i32{
+    ) -> i32 {
         use windows_sys::{
             Win32::Foundation::*, Win32::System::Threading::*, Win32::UI::WindowsAndMessaging::*,
         };
         unsafe {
             let event = CreateEventW(std::ptr::null(), 1, 0, std::ptr::null());
             SetEvent(event);
-            println!("{}",event);
+            println!("{}", event);
             WaitForSingleObject(event, 0);
             CloseHandle(event);
-            let result = MessageBoxA(
+            let event_handler = Event::DialogEventHandler::new();
+            let event = event_handler.set_event(MessageBoxA(
                 dialog_hint.try_into().unwrap(),
                 self.message.as_ptr(),
                 self.title.as_ptr(),
                 dialog_style | button_style,
-            );
-            println!("{}",result);
-            return result;
+            ));
+            println!("{}", event);
+            return event;
         }
     }
 }
 
 #[cfg(linux)]
-impl MessageBox {
+impl MessaddeBox {
     ///
     /// Create a new dialog
     ///
@@ -128,17 +130,26 @@ impl MessageBox {
         &self,
         button_style: ButtonsType,
         dialog_style: MessageType,
-        dialog_hint: DialogFlags,
-    ) {
+        dialog_hints: DialogFlags,
+    ) -> DialogEventType {
         use gtk::prelude::*;
+        use gtk::Window;
+        use crate::Event::*;
+        use gtk::{ButtonsType, DialogFlags, MessageType};
+        gtk::init();
         let dialog = gtk::MessageDialog::new(
-            Some(&window_),
-            window_style,
+            Some(&gtk::Window::new(gtk::WindowType::Toplevel)),
+            dialog_hints,
             dialog_style,
-            button_type,
-            &message,
+            button_style,
+            &self.message,
         );
-        dialog.run();
-        dialog.destroy();
+        let event_handler = Event::DialogEventHandler::new();
+        let event = event_handler.set_event_gtk(dialog.run());
+        println!("{}", event);
+        unsafe {
+            dialog.destroy();
+        }
+        return event;
     }
 }
