@@ -28,7 +28,14 @@ impl Window {
     ///
     /// Create a new window
     ///
-    pub fn new(class: super::windowclass::WindowClass, title: String, width: i32, height: i32, x: i32, y: i32) -> Self {
+    pub fn new(
+        class: super::windowclass::WindowClass,
+        title: String,
+        width: i32,
+        height: i32,
+        x: i32,
+        y: i32,
+    ) -> Self {
         Self {
             class,
             title,
@@ -159,7 +166,14 @@ impl Window {
     ///
     /// Create a new window
     ///
-    pub fn new(class: super::windowclass::WindowClass, title: String, width: i32, height: i32, x: i32, y: i32) -> Self {
+    pub fn new(
+        class: super::windowclass::WindowClass,
+        title: String,
+        width: i32,
+        height: i32,
+        x: i32,
+        y: i32,
+    ) -> Self {
         Self {
             class,
             title,
